Module: VagrantPlugins::Openstack::Action
- Includes:
- Vagrant::Action::Builtin
- Defined in:
- lib/vagrant-openstack-provider/action.rb,
lib/vagrant-openstack-provider/action/is_created.rb,
lib/vagrant-openstack-provider/action/read_state.rb,
lib/vagrant-openstack-provider/action/sync_folders.rb,
lib/vagrant-openstack-provider/action/create_server.rb,
lib/vagrant-openstack-provider/action/delete_server.rb,
lib/vagrant-openstack-provider/action/read_ssh_info.rb,
lib/vagrant-openstack-provider/action/connect_openstack.rb,
lib/vagrant-openstack-provider/action/message_not_created.rb,
lib/vagrant-openstack-provider/action/message_already_created.rb
Defined Under Namespace
Classes: ConnectOpenstack, CreateServer, DeleteServer, IsCreated, MessageAlreadyCreated, MessageNotCreated, NoSyncFolders, ReadSSHInfo, ReadState, RsyncFolders, SyncFolders
Class Method Summary collapse
-
.action_destroy ⇒ Object
This action is called to destroy the remote machine.
-
.action_provision ⇒ Object
This action is called when ‘vagrant provision` is called.
-
.action_read_ssh_info ⇒ Object
This action is called to read the SSH info of the machine.
-
.action_read_state ⇒ Object
This action is called to read the state of the machine.
- .action_ssh ⇒ Object
- .action_ssh_run ⇒ Object
- .action_up ⇒ Object
Class Method Details
.action_destroy ⇒ Object
This action is called to destroy the remote machine.
12 13 14 15 16 17 18 19 20 21 22 23 24 25 |
# File 'lib/vagrant-openstack-provider/action.rb', line 12 def self.action_destroy Vagrant::Action::Builder.new.tap do |b| b.use ConfigValidate b.use Call, IsCreated do |env, b2| if !env[:result] b2.use MessageNotCreated next end b2.use ConnectOpenstack b2.use DeleteServer end end end |
.action_provision ⇒ Object
This action is called when ‘vagrant provision` is called.
28 29 30 31 32 33 34 35 36 37 38 39 40 41 |
# File 'lib/vagrant-openstack-provider/action.rb', line 28 def self.action_provision Vagrant::Action::Builder.new.tap do |b| b.use ConfigValidate b.use Call, IsCreated do |env, b2| if !env[:result] b2.use MessageNotCreated next end b2.use Provision b2.use SyncFolders end end end |
.action_read_ssh_info ⇒ Object
This action is called to read the SSH info of the machine. The resulting state is expected to be put into the :machine_ssh_info key.
46 47 48 49 50 51 52 |
# File 'lib/vagrant-openstack-provider/action.rb', line 46 def self.action_read_ssh_info Vagrant::Action::Builder.new.tap do |b| b.use ConfigValidate b.use ConnectOpenstack b.use ReadSSHInfo end end |
.action_read_state ⇒ Object
This action is called to read the state of the machine. The resulting state is expected to be put into the :machine_state_id key.
57 58 59 60 61 62 63 |
# File 'lib/vagrant-openstack-provider/action.rb', line 57 def self.action_read_state Vagrant::Action::Builder.new.tap do |b| b.use ConfigValidate b.use ConnectOpenstack b.use ReadState end end |
.action_ssh ⇒ Object
65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/vagrant-openstack-provider/action.rb', line 65 def self.action_ssh Vagrant::Action::Builder.new.tap do |b| b.use ConfigValidate b.use Call, IsCreated do |env, b2| if !env[:result] b2.use MessageNotCreated next end b2.use SSHExec end end end |
.action_ssh_run ⇒ Object
79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/vagrant-openstack-provider/action.rb', line 79 def self.action_ssh_run Vagrant::Action::Builder.new.tap do |b| b.use ConfigValidate b.use Call, IsCreated do |env, b2| if !env[:result] b2.use MessageNotCreated next end b2.use SSHRun end end end |
.action_up ⇒ Object
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/vagrant-openstack-provider/action.rb', line 93 def self.action_up Vagrant::Action::Builder.new.tap do |b| b.use ConfigValidate b.use Call, IsCreated do |env, b2| if env[:result] b2.use MessageAlreadyCreated next end b2.use ConnectOpenstack b2.use Provision b2.use SyncFolders b2.use CreateServer end end end |